@@ -12,8 +12,12 @@ def traffic_teaser():
 
 def traffic_jam(km=False):
     traffic_data = traffic_teaser()
-    traffic_jam_length = traffic_data["teaser"]["trafficJamLength"]
-    if km:
-        return {"length": traffic_jam_length / 1000, "unit": "km"}
+
+    if traffic_data and traffic_data.get("teaser"):
+        traffic_jam_length = traffic_data["teaser"]["trafficJamLength"]
+        if km:
+            return {"length": traffic_jam_length / 1000, "unit": "km"}
+        else:
+            return {"length": traffic_jam_length, "unit": "m"}
     else:
-        return {"length": traffic_jam_length, "unit": "m"}
+        return {}
